<TS language="hu" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>A Gridcoin-ról</translation>
    </message>
    <message>
        <source>&lt;b&gt;Gridcoin&lt;/b&gt; </source>
        <translation>&lt;b&gt;Gridcoin &lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Új cím létrehozása</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Új</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>A kiválasztott cím másolása a vágólapra</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Másolás</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>&amp;QR Kód Mutatása</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Írj alá egy üzenetet, hogy bizonyíthasd egy Gridcoin-cím birtoklását</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;Üzenet Aláírása</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Hitelesíts egy üzenetet ahhoz, hogy bebizonyosodjon Gridcoin-cím alapján a feladó kiléte</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Üzenet &amp;Hitelesítése</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Kiválasztott cím törlése a listából</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Címjegyzék</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Ezek a Gridcoin-címeid a fizetések fogadásához. Érdemes minden küldőnek egy külön címet létrehozni, hogy könnyebben követhesd személyenként a tranzakciókat.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Címke &amp;Másolása</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Sz&amp;erkesztés</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Címjegyzék Exportálása</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Hiba exportálás</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Nem lehetett írni a fájlt a következő helyen: %1.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Jelszó párbeszédablak</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Add meg a jelszót</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Új jelszó</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Új jelszó újra</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Triviálisan a sendmoney parancs letiltására szolgál, amennyiben az OS felhasználója kompromittálódik. Nem ad valós biztonságot.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Csak kamatoztatásra</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Tárca kódolása</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ez a művelet a tárcád jelszavának megadását igényli annak megnyitásához.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Tárca feloldása</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Jelszó megváltoztatása</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Írd be a tárca régi és új jelszavát.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Biztosan kódolni akarod a tárcát?</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Figyelmeztetés: Ha kódolod a tárcád és elveszíted annak jelszavát, el fogod &lt;b&gt;VESZÍTENI AZ ÖSSZES ÉRMÉDET&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Biztosan kódolni akarod a tárcát?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Tárca kódolva</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>FONTOS: A pénztárca-fájl korábbi mentéseit ezzel az új, titkosított pénztárca-fájllal kell helyettesíteni. Biztonsági okokból a pénztárca-fájl korábbi titkosítás nélküli mentései haszontalanná válnak amint elkezdi használni az új, titkosított pénztárcát.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Tárca kódolása sikertelen.</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Tárca kódolása belső hiba miatt sikertelen. A tárcád nem lett kódolva.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>A megadott jelszavak nem egyeznek.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Tárca megnyitása sikertelen</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Hibás jelszó.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Jelszó megváltoztatva.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Figyelmeztetés: A Caps Lock billentyű aktív!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Tárca</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Áttekintés</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Tárca általános áttekintése</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Küldés</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Coinok küldése egy Gridcoin címre</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Fogadás</translation>
    </message>
    <message>
        <source>&amp;History</source>
        <translation>&amp;Előzmények</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Tranzakciós előzmények megtekintése</translation>
    </message>
    <message>
        <source>&amp;Favorites</source>
        <translation>&amp;Kedvencek</translation>
    </message>
    <message>
        <source>&amp;Block Explorer</source>
        <translation>&amp;Block felfedező</translation>
    </message>
    <message>
        <source>Block Explorer</source>
        <translation>Block felfedező</translation>
    </message>
    <message>
        <source>&amp;Exchange</source>
        <translation>&amp;Váltó</translation>
    </message>
    <message>
        <source>Web Site</source>
        <translation>Weboldal</translation>
    </message>
    <message>
        <source>&amp;Web Site</source>
        <translation>&amp;Weboldal</translation>
    </message>
    <message>
        <source>&amp;GRC Chat Room</source>
        <translation>&amp;GRC Chat szoba</translation>
    </message>
    <message>
        <source>GRC Chatroom</source>
        <translation>GRC Chatszoba</translation>
    </message>
    <message>
        <source>Gridcoin rewards distributed computing with BOINC</source>
        <translation>A Gridcoin jutalmazza a BOINC-on végzett elosztott számítást</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;A Gridcoinról</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciók...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mutat / Elrejt</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Tárca &amp;titkosítása...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Jelszó &amp;megváltoztatása...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Tárca-titkosító jelszó megváltoztatása</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Üzenet aláírása...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Üzenet &amp;valódiságának ellenőrzése</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Debug ablak</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Hibakereső és diagnosztikai konzol megnyitása</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Súgó</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[teszthálózat]</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Gridcoin kliens</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Naprakész</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Frissítés...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Tranzakció elküldve.</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Beérkező tranzakció</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Tárca &lt;b&gt;kódolva&lt;/b&gt; és jelenleg &lt;b&gt;zárva&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Scraper: waiting on wallet to sync.</source>
        <translation>Scraper: várakozás tárca szinkronizációra.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Hálózati figyelmeztetés</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Mennyiség:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bájtok:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Összeg:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Díj:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Utólagos díj:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Visszajáró:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Megerősítések</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Megerősítve</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Cím másolása</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Címke másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Tranzakcióazonosító másolása</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
    </context>
<context>
    <name>DiagnosticsDialog</name>
    <message>
        <source>Check client version</source>
        <translation>Kliens verzió ellenőrzése</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Cím szerkesztése</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>Cím&amp;ke</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cím</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Új fogadó cím</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Új küldő cím</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Fogadó cím szerkesztése</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Küldő cím szerkesztése</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>A megadott "%1" cím már szerepel a címjegyzékben.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Tárca feloldása sikertelen</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Új kulcs generálása sikertelen</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciók</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Fő</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Hálózat</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>&amp;UPnP port-feltérképezés</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxy portja (pl.: 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Az alkalmazásból való kilépés helyett az eszköztárba kicsinyíti az alkalmazást az ablak bezárásakor. Ez esetben az alkalmazás csak a Kilépés menüponttal zárható be.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Címek megjelenítése a tranzakciólistában</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Kicsinyítés után csak eszköztár-ikont mutass</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Kicsinyítés a tálcára az eszköztár helyett</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>K&amp;icsinyítés záráskor</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Megjelenítés</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Felhasználófelület nye&amp;lve:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Mértékegység:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Válaszd ki az interfészen és érmék küldésekor megjelenítendő alapértelmezett alegységet.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Megszakítás</translation>
    </message>
    <message>
        <source>default</source>
        <translation>alapértelmezett</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>A megadott proxy cím nem érvényes.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Elérhető:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Jelenlegi egyenleg</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Éretlen:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Összesen:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Aktuális egyenleged</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Nem elérhető</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliens verzió</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Információ</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Bekapcsolás ideje</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Kapcsolatok száma</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokklánc</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Aktuális blokkok száma</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Utolsó blokk ideje</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Megnyitás</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konzol</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Hálózati forgalom</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Összesen:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Be:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ki:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Debug naplófájl</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Konzol törlése</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Becsült összes blokk</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Kliens neve</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Navigálhat a fel és le nyilakkal, és &lt;b&gt;Ctrl-L&lt;/b&gt; -vel törölheti a képernyőt.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Írd be azt, hogy &lt;b&gt;help&lt;/b&gt; az elérhető parancsok áttekintéséhez.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Érmék küldése</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Bemenetek...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automatikusan kiválasztva</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fedezethiány!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Mennyiség:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Bájtok:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Összeg:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Díjak:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Utólagos díj:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Küldés több címzettnek egyszerre</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;Címzett hozzáadása</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Mindent &amp;töröl</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Küldés megerősítése</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Küldés</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Küldés megerősítése</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>A címzett címe érvénytelen, kérlek, ellenőrizd.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>A fizetendő összegnek nagyobbnak kell lennie 0-nál.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Nincs ennyi bitcoin az egyenlegeden.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>A küldeni kívánt összeg és a %1 tranzakciós díj együtt meghaladja az egyenlegeden rendelkezésedre álló összeget.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Többször szerepel ugyanaz a cím. Egy küldési műveletben egy címre csak egyszer lehet küldeni.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(nincs címke)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Összeg:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Címzett:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Üzenet:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>Címke:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Cím beillesztése a vágólapról</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Milyen címkével kerüljön be ez a cím a címtáradba?
</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Aláírások - üzenet aláírása/ellenőrzése</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>Üzenet aláírása...</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Aláírhat a címeivel üzeneteket, amivel bizonyíthatja, hogy a címek az önéi. Vigyázzon, hogy ne írjon alá semmi félreérthetőt, mivel a phising támadásokkal megpróbálhatják becsapni, hogy az azonosságát átírja másokra. Csak olyan részletes állításokat írjon alá, amivel egyetért.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Cím beillesztése a vágólapról</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Ide írja az aláírandó üzenetet</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>A jelenleg kiválasztott aláírás másolása a rendszer-vágólapra</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Üzenet &amp;aláírása</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Mindent &amp;töröl</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Üzenet ellenőrzése</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Írja be az aláírás címét, az üzenetet (ügyelve arra, hogy az új-sor, szóköz, tab, stb. karaktereket is pontosan) és az aláírást az üzenet ellenőrzéséhez. Ügyeljen arra, ne gondoljon többet az aláírásról, mint amennyi az aláírt szövegben ténylegesen áll, hogy elkerülje a köztes-ember (man-in-the-middle) támadást.</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>A megadott cím nem érvényes.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Ellenőrizze a címet és próbálja meg újra.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Üzenet aláírása nem sikerült.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Üzenet aláírva.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Az aláírást nem sikerült dekódolni.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Ellenőrizd az aláírást és próbáld újra.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Az üzenet ellenőrzése nem sikerült.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Üzenet ellenőrizve.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Megnyitva %1-ig</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/megerősítetlen</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 megerősítés</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, még nem sikerült elküldeni.</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Űrlap</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ismeretlen</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Címzett</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>saját cím</translation>
    </message>
    <message>
        <source>label</source>
        <translation>címke</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Jóváírás</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>elutasítva</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Terhelés</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tranzakciós díj</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Nettó összeg</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Üzenet</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>true</source>
        <translation>igaz</translation>
    </message>
    <message>
        <source>false</source>
        <translation>hamis</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Tranzakció részletei</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ez a mező a tranzakció részleteit mutatja</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>%1-ig megnyitva</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Megerősítve (%1 megerősítés)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Legenerálva, de még el nem fogadva.</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Erre a címre</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Erről az</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Erre a címre</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Magadnak kifizetve</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(nincs)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Tranzakció állapota. Húzd ide a kurzort, hogy lásd a megerősítések számát.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Tranzakció fogadásának dátuma és időpontja.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tranzakció típusa.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>A tranzakció címzettjének címe.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Az egyenleghez jóváírt vagy ráterhelt összeg.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Ezen a héten</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Ebben a hónapban</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Múlt hónapban</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Ebben az évben</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Tartomány ...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Erre a címre</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Erre a címre</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Magadnak</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Kibányászva</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Más</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimális összeg</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Cím másolása</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Címke másolása</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Összeg másolása</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Tranzakcióazonosító másolása</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Címke szerkesztése</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Tranzakciós részletek megjelenítése</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Megerősítve</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Címke</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cím</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Összeg</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>Azonosító</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Tartomány:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>meddig</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Használat:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Parancsok kilistázása
</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Segítség egy parancsról
</translation>
    </message>
    <message>
        <source>Client Version</source>
        <translation>Kliens verzió</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Figyelem: a -paytxfee nagyon magas.  Ennyi tranzakciós díjat fogsz fizetni, ha elküldöd a tranzakciót.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Egyik hálózati porton sem sikerül hallgatni. Használja a -listen=0 kapcsolót, ha ezt szeretné.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Használd a %s opciót</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Be kell állítani rpcpassword=&lt;password&gt; a konfigurációs fájlban
%s
Ha a fájl nem létezik, hozd létre 'csak a felhasználó által olvasható' fájl engedéllyel</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Étvénytelen -paytxfee=&lt;összeg&gt; összeg: '%s'</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Érvénytelen -proxy cím: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Csatlakozási cím (-bind address) feloldása nem sikerült: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Külső cím (-externalip address) feloldása nem sikerült: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Hiba a wallet.dat betöltése közben: meghibásodott tárca</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Hiba az wallet.dat betöltése közben</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Címek betöltése...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>A %s nem elérhető ezen a gépen (bind returned error %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Étvénytelen összeg</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Ismeretlen hálózat lett megadva -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Nincs elég bitcoinod.</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Blokkindex betöltése...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Tárca betöltése...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Nem sikerült az alapértelmezett címet írni.</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Újraszkennelés...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Betöltés befejezve.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
</TS>